@@ -1,8 +1,5 @@
-from fuzzywuzzy import fuzz
-from logging import getLogger
-from typing import Dict, Optional
+from typing import Dict
 
-logger = getLogger(__name__)
 
 JENIS_PENGGUNAAN: Dict[int, Dict[int, str]] = {
     1: {
@@ -43,20 +40,3 @@ JENIS_KOMPONEN = {
     2: "Kegiatan Pendukung",
     3: "Kegiatan Lainnya",
 }
-
-
-def get_key(nama: str, data: Dict[int, str] = JENIS_KOMPONEN) -> Optional[int]:
-    nama = nama.replace("\r\n", " ")
-    for k, v in data.items():
-        if v == nama:
-            return k
-    return None
-
-
-def get_fuzz(f: str, data: Dict[int, str], default: int = 0, ok: int = 80) -> int:
-    for k, v in data.items():
-        if fuzz.ratio(v, f) > ok:
-            logger.debug(f"Key dari {f} ditemukan")
-            return k
-    logger.debug(f"Key dari {f} tidak ditemukan")
-    return default
