@@ -4,6 +4,7 @@ from dataclasses import dataclass
 from typing import List, Optional, Type
 from simdak.exception import DataKosongException
 from . import BaseSimdakPaud, Rab
+from .utils import try_find_one
 
 
 @dataclass
@@ -51,19 +52,22 @@ class Rkas(BaseSimdakPaud):
         results = save_as.from_table(table[1])
         return results
 
-    def create(self, rkas_data: Rab, semester_id: int = 20201) -> Optional[Rab]:
+    def create(
+        self, rkas_data: Rab, semester_id: int = 20201, update_id: bool = False
+    ) -> Rab:
         data = rkas_data.as_data()
         data.update({"yt0": "Simpan"})
         semester = semester_id or self.semester_id
         url = self._base_url + f"boppaudrkas/create/id/{self.id}/semester_id/{semester}"
-        res = self._session.post(url, data=data)
-        if not res.ok:
-            return None
+        res = self._session.post(url, data=data, allow_redirects=update_id)
+        if not update_id or not res.ok:
+            return rkas_data
         soup = BeautifulSoup(res.text, "html.parser")
         table: List[Tag] = soup.findAll("table")
         if not table or len(table) != 2:
             raise DataKosongException(
                 f"Data tidak ditemukan untuk rkas [{self.id}] semester [{semester}]"
             )
-        tr: Tag = table[-1].findAll("tr")[-1]
-        return Rab.from_tr(tr)
+        return try_find_one(
+            Rab.from_table(table), rkas_data, lambda n: getattr(n, "jenisbelanja")
+        )
